@@ -1,5 +1,5 @@
 package MooseX::Role::Pluggable::Plugin;
-$MooseX::Role::Pluggable::Plugin::VERSION = '0.05';
+$MooseX::Role::Pluggable::Plugin::VERSION = '0.06';
 # ABSTRACT: Role for plugins to consume
 use Moose::Role;
 use Moose::Util::TypeConstraints;
@@ -36,7 +36,7 @@ MooseX::Role::Pluggable::Plugin - Role for plugins to consume
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -84,11 +84,11 @@ under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
